@@ -2,20 +2,20 @@ package db_client
 
 import (
 	"context"
-	"github.com/jackc/pgx/v4"
-	"github.com/jackc/pgx/v4/pgxpool"
-	"github.com/spf13/viper"
-	"golang.org/x/sync/semaphore"
 	"log"
 	"sort"
 	"sync"
 
+	"github.com/jackc/pgx/v5"
+	"github.com/jackc/pgx/v5/pgxpool"
+	"github.com/spf13/viper"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/schema"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
 	"github.com/turbot/steampipe/pkg/utils"
+	"golang.org/x/sync/semaphore"
 )
 
 // DbClient wraps over `sql.DB` and gives an interface to the database
@@ -92,7 +92,7 @@ func NewDbClient(ctx context.Context, connectionString string, onConnectionCallb
 }
 
 func (c *DbClient) setShouldShowTiming(ctx context.Context, session *db_common.DatabaseSession) {
-	currentShowTimingFlag := viper.GetBool(constants.ArgTiming) && viper.GetString(constants.ArgOutput) == constants.OutputFormatTable
+	currentShowTimingFlag := viper.GetBool(constants.ArgTiming)
 
 	// if we are turning timing ON, fetch the ScanMetadataMaxId
 	// to ensure we only select the relevant scan metadata table entries
@@ -162,7 +162,7 @@ func (c *DbClient) RefreshSessions(ctx context.Context) *db_common.AcquireSessio
 	}
 	sessionResult := c.AcquireSession(ctx)
 	if sessionResult.Session != nil {
-		sessionResult.Session.Close(utils.IsContextCancelled(ctx))
+		sessionResult.Session.Close(error_helpers.IsContextCanceled(ctx))
 	}
 	return sessionResult
 }
@@ -185,7 +185,7 @@ func (c *DbClient) refreshDbClient(ctx context.Context) error {
 }
 
 // RefreshConnectionAndSearchPaths implements Client
-func (c *DbClient) RefreshConnectionAndSearchPaths(ctx context.Context) *steampipeconfig.RefreshConnectionResult {
+func (c *DbClient) RefreshConnectionAndSearchPaths(ctx context.Context, _ ...string) *steampipeconfig.RefreshConnectionResult {
 	// base db client does not refresh connections, it just sets search path
 	// (only local db client refreshed connections)
 	res := &steampipeconfig.RefreshConnectionResult{}
