@@ -5,6 +5,11 @@ import (
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
+// cache resource schemas
+var resourceSchemaCache = make(map[string]*hcl.BodySchema)
+
+// TODO  [node_reuse] Replace all block type with consts https://github.com/turbot/steampipe/issues/2922
+
 var ConfigBlockSchema = &hcl.BodySchema{
 	Attributes: []hcl.AttributeSchema{},
 	Blocks: []hcl.BlockHeaderSchema{
@@ -119,9 +124,21 @@ var WorkspaceBlockSchema = &hcl.BodySchema{
 			Type:       modconfig.BlockTypeText,
 			LabelNames: []string{"name"},
 		},
+		{
+			Type:       modconfig.BlockTypeNode,
+			LabelNames: []string{"name"},
+		},
+		{
+			Type:       modconfig.BlockTypeEdge,
+			LabelNames: []string{"name"},
+		},
 		{
 			Type: modconfig.BlockTypeLocals,
 		},
+		{
+			Type:       modconfig.BlockTypeCategory,
+			LabelNames: []string{"name"},
+		},
 	},
 }
 
@@ -149,11 +166,8 @@ var RequireModBlockSchema = &hcl.BodySchema{
 	},
 }
 
-// DashboardBlockSchema is used purely to validate dashboard child blocks
+// DashboardBlockSchema is only used to validate the blocks of a Dashboard
 var DashboardBlockSchema = &hcl.BodySchema{
-	Attributes: []hcl.AttributeSchema{
-		{Name: "args"},
-	},
 	Blocks: []hcl.BlockHeaderSchema{
 		{
 			Type:       modconfig.BlockTypeInput,
@@ -163,6 +177,9 @@ var DashboardBlockSchema = &hcl.BodySchema{
 			Type:       modconfig.BlockTypeParam,
 			LabelNames: []string{"name"},
 		},
+		{
+			Type: modconfig.BlockTypeWith,
+		},
 		{
 			Type: modconfig.BlockTypeContainer,
 		},
@@ -199,11 +216,8 @@ var DashboardBlockSchema = &hcl.BodySchema{
 	},
 }
 
-// DashboardContainerBlockSchema contains the DashboardContainer attributes which cannot be automatically decoded
+// DashboardContainerBlockSchema is only used to validate the blocks of a DashboardContainer
 var DashboardContainerBlockSchema = &hcl.BodySchema{
-	Attributes: []hcl.AttributeSchema{
-		{Name: "args"},
-	},
 	Blocks: []hcl.BlockHeaderSchema{
 		{
 			Type:       modconfig.BlockTypeInput,
@@ -265,6 +279,8 @@ var BenchmarkBlockSchema = &hcl.BodySchema{
 }
 
 // QueryProviderBlockSchema schema for all blocks satisfying QueryProvider interface
+// NOTE: these are just the blocks/attributes that are explicitly decoded
+// other query provider properties are implicitly decoded using tags
 var QueryProviderBlockSchema = &hcl.BodySchema{
 	Attributes: []hcl.AttributeSchema{
 		{Name: "args"},
@@ -274,12 +290,16 @@ var QueryProviderBlockSchema = &hcl.BodySchema{
 			Type:       "param",
 			LabelNames: []string{"name"},
 		},
+		{
+			Type:       "with",
+			LabelNames: []string{"name"},
+		},
 	},
 }
 
-// EdgeAndNodeProviderSchema is used to decode graph/hierarchy/flow
+// NodeAndEdgeProviderSchema is used to decode graph/hierarchy/flow
 // (EXCEPT categories)
-var EdgeAndNodeProviderSchema = &hcl.BodySchema{
+var NodeAndEdgeProviderSchema = &hcl.BodySchema{
 	Attributes: []hcl.AttributeSchema{
 		{Name: "args"},
 	},
@@ -292,17 +312,15 @@ var EdgeAndNodeProviderSchema = &hcl.BodySchema{
 			Type:       "category",
 			LabelNames: []string{"name"},
 		},
-	},
-}
-
-// EdgeAndNodeProviderBlockSchema is used to validate child blocks
-var EdgeAndNodeProviderBlockSchema = &hcl.BodySchema{
-	Blocks: []hcl.BlockHeaderSchema{
 		{
-			Type: "param",
+			Type:       "with",
+			LabelNames: []string{"name"},
 		},
 		{
-			Type: "category",
+			Type: modconfig.BlockTypeNode,
+		},
+		{
+			Type: modconfig.BlockTypeEdge,
 		},
 	},
 }
